@@ -425,8 +425,9 @@ class RESTAPI :
             if len(leagues) == 0 or leagues == [] :
                 api_url=URL['leagues'].format(url='/')
                 league = r_api.get_league_by_summoner_id(summoner['id'])
+                
                 print(league)
-                self.post_league(league[0])
+                self.post_league(league)
 
             championMastery = self.get_championmastery_by_championid_and_summonerid(body['championid'], summoner['id'])
             print(championMastery)
@@ -434,7 +435,7 @@ class RESTAPI :
                 api_url=URL['championmasteries'].format(url='/')
                 championMastery = r_api.get_champ_mastery_by_summoner_id_and_champ_id(summoner['id'], participant['championId'])
                 print(championMastery)
-                self.post_championMastery(championMastery)
+                self.post_championMastery(championMastery[0])
         
             response = self.get_matchparticipant_by_matchid_and_puuid(match['metadata']['matchId'], puuid)
             if (len(response) == 0) :
